Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/npm/cli.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulian Møller Ellehauge <jumoel@github.com>2022-06-02 00:11:58 +0300
committerGitHub <noreply@github.com>2022-06-02 00:11:58 +0300
commita8ae17775a24ccbaf4570530d7433e0d290b3793 (patch)
tree6104c2ef20d04c475f45be88146ebbe23b73cb1d /tap-snapshots/test/lib
parentaee6fc857458ac660bf90ecd0af94212c7269fd7 (diff)
feat: Add `--auth-type=webauthn` flag (#4931)
* feat: Add --use-webauth flag * Add docs * Switch from a separate flag to a variation of auth-type * Update snapshot
Diffstat (limited to 'tap-snapshots/test/lib')
-rw-r--r--tap-snapshots/test/lib/load-all-commands.js.test.cjs2
-rw-r--r--tap-snapshots/test/lib/npm.js.test.cjs2
-rw-r--r--tap-snapshots/test/lib/utils/config/definitions.js.test.cjs8
-rw-r--r--tap-snapshots/test/lib/utils/config/describe-all.js.test.cjs8
4 files changed, 14 insertions, 6 deletions
diff --git a/tap-snapshots/test/lib/load-all-commands.js.test.cjs b/tap-snapshots/test/lib/load-all-commands.js.test.cjs
index 7bcdd949b..802fa8de9 100644
--- a/tap-snapshots/test/lib/load-all-commands.js.test.cjs
+++ b/tap-snapshots/test/lib/load-all-commands.js.test.cjs
@@ -33,6 +33,7 @@ npm adduser
Options:
[--registry <registry>] [--scope <@scope>]
+[--auth-type <legacy|webauthn|sso|saml|oauth>]
aliases: login, add-user
@@ -523,6 +524,7 @@ npm adduser
Options:
[--registry <registry>] [--scope <@scope>]
+[--auth-type <legacy|webauthn|sso|saml|oauth>]
aliases: login, add-user
diff --git a/tap-snapshots/test/lib/npm.js.test.cjs b/tap-snapshots/test/lib/npm.js.test.cjs
index d15cae442..b2443e894 100644
--- a/tap-snapshots/test/lib/npm.js.test.cjs
+++ b/tap-snapshots/test/lib/npm.js.test.cjs
@@ -190,6 +190,7 @@ All commands:
Options:
[--registry <registry>] [--scope <@scope>]
+ [--auth-type <legacy|webauthn|sso|saml|oauth>]
aliases: login, add-user
@@ -601,6 +602,7 @@ All commands:
Options:
[--registry <registry>] [--scope <@scope>]
+ [--auth-type <legacy|webauthn|sso|saml|oauth>]
aliases: login, add-user
diff --git a/tap-snapshots/test/lib/utils/config/definitions.js.test.cjs b/tap-snapshots/test/lib/utils/config/definitions.js.test.cjs
index b12dccdb7..d67f3e6fe 100644
--- a/tap-snapshots/test/lib/utils/config/definitions.js.test.cjs
+++ b/tap-snapshots/test/lib/utils/config/definitions.js.test.cjs
@@ -253,11 +253,13 @@ exports[`test/lib/utils/config/definitions.js TAP > config description for auth-
#### \`auth-type\`
* Default: "legacy"
-* Type: "legacy", "sso", "saml", or "oauth"
-* DEPRECATED: This method of SSO/SAML/OAuth is deprecated and will be removed
- in a future version of npm in favor of web-based login.
+* Type: "legacy", "webauthn", "sso", "saml", or "oauth"
+* DEPRECATED: The SSO/SAML/OAuth methods are deprecated and will be removed in
+ a future version of npm in favor of web-based login.
What authentication strategy to use with \`adduser\`/\`login\`.
+
+Pass \`webauthn\` to use a web-based login.
`
exports[`test/lib/utils/config/definitions.js TAP > config description for before 1`] = `
diff --git a/tap-snapshots/test/lib/utils/config/describe-all.js.test.cjs b/tap-snapshots/test/lib/utils/config/describe-all.js.test.cjs
index cacbe96a7..853e758dc 100644
--- a/tap-snapshots/test/lib/utils/config/describe-all.js.test.cjs
+++ b/tap-snapshots/test/lib/utils/config/describe-all.js.test.cjs
@@ -1764,12 +1764,14 @@ When set to \`dev\` or \`development\`, this is an alias for \`--include=dev\`.
#### \`auth-type\`
* Default: "legacy"
-* Type: "legacy", "sso", "saml", or "oauth"
-* DEPRECATED: This method of SSO/SAML/OAuth is deprecated and will be removed
- in a future version of npm in favor of web-based login.
+* Type: "legacy", "webauthn", "sso", "saml", or "oauth"
+* DEPRECATED: The SSO/SAML/OAuth methods are deprecated and will be removed in
+ a future version of npm in favor of web-based login.
What authentication strategy to use with \`adduser\`/\`login\`.
+Pass \`webauthn\` to use a web-based login.
+
<!-- automatically generated, do not edit manually -->
<!-- see lib/utils/config/definitions.js -->